@@ -12,7 +12,6 @@ require_relative "document/bounding_box"
 require_relative "document/column_box"
 require_relative "document/internals"
 require_relative "document/span"
-require_relative "document/graphics_state"
 
 module Prawn
 
@@ -53,7 +52,6 @@ module Prawn
     include Prawn::Document::Internals
     include PDF::Core::Annotations
     include PDF::Core::Destinations
-    include Prawn::Document::GraphicsState
     include Prawn::Document::Security
     include Prawn::Text
     include Prawn::Graphics
@@ -97,7 +95,7 @@ module Prawn
     end
 
     # @private
-    def self.inherited(base) 
+    def self.inherited(base)
       extensions.each { |e| base.extensions << e }
     end
 
@@ -148,7 +146,7 @@ module Prawn
     # Creates a new PDF Document.  The following options are available (with
     # the default values marked in [])
     #
-    # <tt>:page_size</tt>:: One of the Document::PageGeometry sizes [LETTER]
+    # <tt>:page_size</tt>:: One of the PDF::Core::PageGeometry sizes [LETTER]
     # <tt>:page_layout</tt>:: Either <tt>:portrait</tt> or <tt>:landscape</tt>
     # <tt>:margin</tt>:: Sets the margin on all sides in points [0.5 inch]
     # <tt>:left_margin</tt>:: Sets the left margin in points [0.5 inch]
@@ -202,9 +200,9 @@ module Prawn
       self.class.extensions.reverse_each { |e| extend e }
       @internal_state = PDF::Core::DocumentState.new(options)
       @internal_state.populate_pages_from_store(self)
-      min_version(state.store.min_version) if state.store.min_version
+      renderer.min_version(state.store.min_version) if state.store.min_version
 
-      min_version(1.6) if options[:print_scaling] == :none
+      renderer.min_version(1.6) if options[:print_scaling] == :none
 
       @background = options[:background]
       @background_scale = options[:background_scale] || 1
@@ -349,23 +347,13 @@ module Prawn
     # Renders the PDF document to string.
     # Pass an open file descriptor to render to file.
     #
-    def render(output = StringIO.new)
-      if output.instance_of?(StringIO)
-        output.set_encoding(::Encoding::ASCII_8BIT)
+    def render(*a, &b)
+      (1..page_count).each do |i|
+        go_to_page i
+        repeaters.each { |r| r.run(i) }
       end
-      finalize_all_page_contents
 
-      render_header(output)
-      render_body(output)
-      render_xref(output)
-      render_trailer(output)
-      if output.instance_of?(StringIO)
-        str = output.string
-        str.force_encoding(::Encoding::ASCII_8BIT)
-        return str
-      else
-        return nil
-      end
+      renderer.render(*a, &b)
     end
 
     # Renders the PDF document to file.
@@ -567,13 +555,6 @@ module Prawn
       end
     end
 
-    # Returns true if content streams will be compressed before rendering,
-    # false otherwise
-    #
-    def compression_enabled?
-      !!state.compress
-    end
-
     # @group Experimental API
 
     # Attempts to group the given block vertically within the current context.
@@ -587,7 +568,7 @@ module Prawn
     #
     # @private
     def group(*a, &b)
-      raise NotImplementedError, 
+      raise NotImplementedError,
         "Document#group has been disabled because its implementation "+
         "lead to corrupted documents whenever a page boundary was "+
         "crossed. We will try to work on reimplementing it in a "+
@@ -596,7 +577,7 @@ module Prawn
 
     # @private
     def transaction
-      raise NotImplementedError, 
+      raise NotImplementedError,
         "Document#transaction has been disabled because its implementation "+
         "lead to corrupted documents whenever a page boundary was "+
         "crossed. We will try to work on reimplementing it in a "+
@@ -629,8 +610,8 @@ module Prawn
     end
 
     # @private
-   
-    def mask(*fields) 
+
+    def mask(*fields)
      # Stores the current state of the named attributes, executes the block, and
      # then restores the original values after the block has executed.
      # -- I will remove the nodoc if/when this feature is a little less hacky
@@ -696,7 +677,7 @@ module Prawn
 
       # we must update bounding box if not flowing from the previous page
       #
-      @bounding_box = @margin_box unless @bounding_box && @bounding_box.parent    
+      @bounding_box = @margin_box unless @bounding_box && @bounding_box.parent
     end
 
     def apply_margin_options(options)
