@@ -10,7 +10,7 @@ require 'digest/md5'
 
 require 'pdf/core/byte_string'
 
-require 'prawn/security/arcfour'
+require_relative 'security/arcfour'
 
 module Prawn
   class Document
@@ -213,7 +213,7 @@ module PDF
     # from the indirect object referencing obj.
     #
     # @private
-    def EncryptedPdfObject(obj, key, id, gen, in_content_stream=false) 
+    def EncryptedPdfObject(obj, key, id, gen, in_content_stream=false)
       case obj
       when Array
         "[" << obj.map { |e|
