@@ -11,7 +11,7 @@ module Prawn
   module Text
     module Formatted
       # @group Stable API
-      
+
       # Draws the requested formatted text into a box. When the text overflows
       # the rectangle shrink to fit or truncate the text. Text boxes are
       # independent of the document y position.
@@ -107,13 +107,13 @@ module Prawn
         # used, the text that would have been successfully printed)
         attr_reader :text
 
-        # True iff nothing printed (or, if <tt>dry_run</tt> was
+        # True if nothing printed (or, if <tt>dry_run</tt> was
         # used, nothing would have been successfully printed)
         def nothing_printed?
           @nothing_printed
         end
 
-        # True iff everything printed (or, if <tt>dry_run</tt> was
+        # True if everything printed (or, if <tt>dry_run</tt> was
         # used, everything would have been successfully printed)
         def everything_printed?
           @everything_printed
@@ -144,6 +144,7 @@ module Prawn
           self.class.extensions.reverse_each { |e| extend e }
 
           @overflow          = options[:overflow] || :truncate
+          @disable_wrap_by_char = options[:disable_wrap_by_char]
 
           self.original_text = formatted_text
           @text              = nil
@@ -211,11 +212,7 @@ module Prawn
               @document.text_rendering_mode(@mode) do
                 process_options
 
-                if @skip_encoding
-                  text = original_text
-                else
-                  text = normalize_encoding
-                end
+                text = normalized_text(flags)
 
                 @document.font_size(@font_size) do
                   shrink_to_fit(text) if @overflow == :shrink_to_fit
@@ -293,7 +290,7 @@ module Prawn
         end
 
         # @group Extension API
-        
+
         # Example (see Prawn::Text::Core::Formatted::Wrap for what is required
         # of the wrap method if you want to override the default wrapping
         # algorithm):
@@ -335,6 +332,7 @@ module Prawn
                                               :align, :valign,
                                               :rotate, :rotate_around,
                                               :overflow, :min_font_size,
+                                              :disable_wrap_by_char,
                                               :leading, :character_spacing,
                                               :mode, :single_line,
                                               :skip_encoding,
@@ -346,6 +344,18 @@ module Prawn
 
         private
 
+        def normalized_text(flags)
+          if @skip_encoding
+            text = original_text
+          else
+            text = normalize_encoding
+          end
+
+          text.each { |t| t.delete(:color) } if flags[:dry_run]
+
+          text
+        end
+
         def original_text
           @original_array.collect { |hash| hash.dup }
         end
@@ -390,33 +400,37 @@ module Prawn
 
           original_font = @document.font.family
           fragment_font = hash[:font] || original_font
-          @document.font(fragment_font)
 
           fallback_fonts = @fallback_fonts.dup
           # always default back to the current font if the glyph is missing from
           # all fonts
           fallback_fonts << fragment_font
 
-          hash[:text].each_char do |char|
-            @document.font(fragment_font)
-            font_glyph_pairs << [find_font_for_this_glyph(char,
-                                                          @document.font.family,
-                                                          fallback_fonts.dup),
-                                 char]
+          @document.save_font do
+            hash[:text].each_char do |char|
+              font_glyph_pairs << [find_font_for_this_glyph(char,
+                                                            fragment_font,
+                                                            fallback_fonts.dup),
+                                   char]
+            end
           end
 
-          @document.font(original_font)
+          # Don't add a :font to fragments if it wasn't there originally
+          if hash[:font].nil?
+            font_glyph_pairs.each do |pair|
+              pair[0] = nil if pair[0] == original_font
+            end
+          end
 
           form_fragments_from_like_font_glyph_pairs(font_glyph_pairs, hash)
         end
 
         def find_font_for_this_glyph(char, current_font, fallback_fonts)
+          @document.font(current_font)
           if fallback_fonts.length == 0 || @document.font.glyph_present?(char)
             current_font
           else
-            current_font = fallback_fonts.shift
-            @document.font(current_font)
-            find_font_for_this_glyph(char, @document.font.family, fallback_fonts)
+            find_font_for_this_glyph(char, fallback_fonts.shift, fallback_fonts)
           end
         end
 
@@ -426,11 +440,11 @@ module Prawn
           current_font = nil
 
           font_glyph_pairs.each do |font, char|
-            if font != current_font
+            if font != current_font || fragments.count == 0
               current_font = font
               fragment = hash.dup
               fragment[:text] = char
-              fragment[:font] = font
+              fragment[:font] = font unless font.nil?
               fragments << fragment
             else
               fragment[:text] += char
@@ -484,16 +498,27 @@ module Prawn
         # Decrease the font size until the text fits or the min font
         # size is reached
         def shrink_to_fit(text)
-          wrap(text)
-          until @everything_printed || @font_size <= @min_font_size
+          loop do
+            if @disable_wrap_by_char && @font_size > @min_font_size
+              begin
+                wrap(text)
+              rescue Errors::CannotFit
+                # Ignore errors while we can still attempt smaller
+                # font sizes.
+              end
+            else
+              wrap(text)
+            end
+
+            break if @everything_printed || @font_size <= @min_font_size
+
             @font_size = [@font_size - 0.5, @min_font_size].max
             @document.font_size = @font_size
-            wrap(text)
           end
         end
 
         def process_options
-          # must be performed within a save_font bock because
+          # must be performed within a save_font block because
           # document.process_text_options sets the font
           @document.process_text_options(@options)
           @font_size = @options[:size]
