@@ -5,11 +5,11 @@
 require File.expand_path(File.join(File.dirname(__FILE__),
                                    %w[.. example_helper]))
 
-Prawn::Example.generate("document_and_page_options.pdf",
+Prawn::ManualBuilder::Example.generate("document_and_page_options.pdf",
                         :page_size => "FOLIO") do
-  
+
   package "document_and_page_options" do |p|
-    
+
     p.example "page_size",    :eval_source => false, :full_source => true
     p.example "page_margins", :eval_source => false, :full_source => true
     p.example "background",   :eval_source => false, :full_source => true
@@ -27,6 +27,6 @@ Prawn::Example.generate("document_and_page_options.pdf",
             "How to add metadata to the generated PDF"
           )
     end
-    
+
   end
 end
