@@ -410,7 +410,7 @@ describe "#text" do
   end
 
   describe "#shrink_to_fit with special utf-8 text" do
-    it "Should not throw an exception", 
+    it "Should not throw an exception",
         :unresolved, :issue => 603 do
       pages = 0
       doc = Prawn::Document.new(page_size: 'A4', margin: [2, 2, 2, 2]) do |pdf|
@@ -434,4 +434,23 @@ describe "#text" do
     })
     pdf.fallback_fonts = ["dejavu"]
   end
+
+  describe "fallback_fonts" do
+    it "should preserve font style" do
+      create_pdf
+
+      @pdf.fallback_fonts ["Helvetica"]
+      @pdf.font "Times-Roman", :style => :italic do
+        @pdf.text "hello"
+      end
+
+      text = PDF::Inspector::Text.analyze(@pdf.render)
+      fonts_used = text.font_settings.map { |e| e[:name] }
+
+      fonts_used.length.should == 1
+      fonts_used[0].should == :"Times-Italic"
+      text.strings[0].should == "hello"
+    end
+  end
+
 end
